(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(require('node:path'), require('node:fs'), require('node:url'), require('inquirer')) :
    typeof define === 'function' && define.amd ? define(['node:path', 'node:fs', 'node:url', 'inquirer'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.node_path, global.node_fs, global.node_url, global.inquirer));
})(this, (function (node_path, node_fs, node_url, inquirer) { 'use strict';

    const getCurDir = url => {
        return node_url.fileURLToPath(url);
    };
    /**
     * 判断一个url是不是目录
     * @param {*} dir 检测的url
     * @returns
     */
    const isDir = path => {
        try {
            var stat = node_fs.lstatSync(path);
            const flag = stat.isDirectory();
            return flag;
        } catch (e) {
            return false;
        }
    };

    const mkdir = path => {
        try {
            node_fs.mkdirSync(path);
            return true;
        } catch (error) {
            return false;
        }
    };

    const copyTo = (src, dest) => {
        node_fs.createReadStream(src).pipe(node_fs.createWriteStream(dest));
    };

    const copyDir = (src, dest) => {
        if (isDir(src) && isDir(dest)) {
            const dirList = node_fs.readdirSync(src);
            dirList.forEach(f => {
                const tmpSrc = node_path.resolve(src, f);
                const tmpDest = node_path.resolve(dest, f);
                if (isDir(tmpSrc)) {
                    if (node_fs.existsSync(tmpDest)) {
                        copyDir(tmpSrc, tmpDest);
                    } else {
                        const flag = mkdir(tmpDest);
                        if (!flag) {
                            throw new Error(`目录创建失败：创建失败的目录路径-${tmpDest}`);
                        } else {
                            copyDir(tmpSrc, tmpDest);
                        }
                    }
                } else {
                    copyTo(tmpSrc, tmpDest);
                }
            });
        } else {
            throw new Error(`copyDir的两个参数都必须是文件夹类型`);
        }
    };

    const root = getCurDir((typeof document === 'undefined' && typeof location === 'undefined' ? new (require('u' + 'rl').URL)('file:' + __filename).href : typeof document === 'undefined' ? location.href : (document.currentScript && document.currentScript.src || new URL('cli.js', document.baseURI).href))).replace("bin\\index.mjs", "");

    inquirer
        .prompt([
            {
                type: "input", //type： input, number, confirm, list, checkbox ...
                name: "name", // key 名
                message: "project name", // 提示信息
                default: "project-name", // 默认值
            },
            {
                type: "list", //type： input, number, confirm, list, checkbox ...
                name: "vue-version", // key 名
                message: "选择vue版本", // 提示信息
                choices: ["vue2", "vue3", "vue3-webpack"],
                default: "vue3-webpack", // 默认值
            },
        ])
        .then(answers => {
            // 打印互用输入结果
            const map = {
                vue2: "vue2",
                vue3: "vue",
                "vue3-webpack": "vue-webpack",
            };

            const version = answers["vue-version"];
            answers.name;

            const dist = node_path.resolve(root, "dist");
            const src = node_path.resolve(root, `template\\${map[version]}`);
            console.log(answers, src);
            copyDir(src, dist);
        });

}));
